# wynncraft-waypoint-utils
Utilities for managing waypoints on Wynncraft

## Requirements
- Python 3

## Examples

Radius Based Filtering
```bash
wynncraft-waypoint-utils --input in1.json in2.json --filter-radius=3 --output out.json
```
